@@ -233,7 +233,7 @@ def get_gifNimage(link, file_name_show=False, dict_appearance=False, show_error_
             if os.path.isfile(file_name_and_type) == True:
                 active_link_or_file_exist = True
             if show_error_logs == True:
-                logging.exception('Caught an error [in code used: except OSError]: no image in current folder, or active link from web (with image), or both.' + str(ose))
+                logging.oserror('Caught an error [in code used: except OSError]: no image in current folder, or active link from web (with image), or both.' + str(ose))
                 print('Caught an error [in code used: except OSError]: no image in current folder, or active link from web (with image), or both.')
         else:
             # Checking if file exist
@@ -252,25 +252,31 @@ def get_gifNimage(link, file_name_show=False, dict_appearance=False, show_error_
                 print('dict_for_links second appearance (in finnaly statement):', dict_for_links)
             
             """Converting svg and webp file type - if it happend"""
-            if active_link_or_file_exist == True and (image_type_index == 'svg' or image_type_index == 'webp'):
-#                 try:
-                # https://stackoverflow.com/questions/6589358/convert-svg-to-png-in-python
-                # Convert svg to png:
-                drawing = svg2rlg(file_name_and_type)
-                png = ".png"
-                renderPM.drawToFile(drawing, file_name + png, fmt="PNG")
-
-                # Removing svg file from folder:
-                """
-                We don't need two formats of the file_name. 
-                So, we remove old one, 
-                so there will be less garbage in folder.
-                """
-                os.remove(file_name_and_type)
-                file_name_and_type = file_name + '.png'
-#                 # Test:
-#                 print('The new file name and type:', file_name_and_type)
+            try:
+                if active_link_or_file_exist == True and (image_type_index == 'svg' or image_type_index == 'webp'):
+    #                 try:
+                    # https://stackoverflow.com/questions/6589358/convert-svg-to-png-in-python
+                    # Convert svg to png:
+                    drawing = svg2rlg(file_name_and_type)
+                    png = ".png"
+                    renderPM.drawToFile(drawing, file_name + png, fmt="PNG")
 
+                    # Removing svg file from folder:
+                    """
+                    We don't need two formats of the file_name. 
+                    So, we remove old one, 
+                    so there will be less garbage in folder.
+                    """
+                    os.remove(file_name_and_type)
+                    file_name_and_type = file_name + '.png'
+    #                 # Test:
+    #                 print('The new file name and type:', file_name_and_type)
+            except Exception as e:
+                if os.path.isfile(file_name_and_type) == True:
+                    active_link_or_file_exist = True
+                if show_error_logs == True:
+                    logging.exception('Caught an error [in code used: except Exception]: no image in current folder, or active link from web (with image), or both.' + str(e))
+                    print('Caught an error [in code used: except Exception]: no image in current folder, or active link from web (with image), or both.')
 
         # Return file name:
             # Checking if file exist
